@@ -7,6 +7,7 @@ import (
 	"github.com/blacktop/go-macho"
 	"github.com/blacktop/ipsw/internal/search"
 	"github.com/blacktop/ipsw/internal/utils"
+	"golang.org/x/exp/maps"
 )
 
 type DiffConfig struct {
@@ -70,7 +71,11 @@ func GenerateDiffInfo(m *macho.File, conf *DiffConfig) *DiffInfo {
 	var strs []string
 	if conf.CStrings {
 		if cs, err := m.GetCStrings(); err == nil {
-			strs = cs
+			for _, val := range cs {
+				str2addr := maps.Keys(val)
+				strs = append(strs, str2addr...)
+			}
+			slices.Sort(strs)
 		}
 	}
 	return &DiffInfo{
