@@ -300,12 +300,16 @@ type CacheImageInfo struct {
 	Pad            uint32
 }
 
+type CacheSlidePointer interface {
+	Raw() uint64
+}
+
 type Rebase struct {
-	CacheFileOffset uint64 `json:"cache_file_offset,omitempty"`
-	CacheVMAddress  uint64 `json:"cache_vm_address,omitempty"`
-	Target          uint64 `json:"target,omitempty"`
-	Pointer         uint64 `json:"pointer,omitempty"`
-	Symbol          string `json:"symbol,omitempty"`
+	CacheFileOffset uint64            `json:"cache_file_offset,omitempty"`
+	CacheVMAddress  uint64            `json:"cache_vm_address,omitempty"`
+	Target          uint64            `json:"target,omitempty"`
+	Pointer         CacheSlidePointer `json:"pointer,omitempty"`
+	Symbol          string            `json:"symbol,omitempty"`
 }
 
 type slideInfo interface {
@@ -373,6 +377,12 @@ func (i CacheSlideInfo2) SlidePointer(ptr uint64) uint64 {
 	return 0
 }
 
+type CacheSlidePointer2 uint64
+
+func (p CacheSlidePointer2) Raw() uint64 {
+	return uint64(p)
+}
+
 const (
 	DYLD_CACHE_SLIDE_PAGE_ATTRS          = 0xC000 // high bits of uint16_t are flags
 	DYLD_CACHE_SLIDE_PAGE_ATTR_EXTRA     = 0x8000 // index is into extras array (not starts array)
@@ -567,6 +577,20 @@ func (i CacheSlideInfo4) SlidePointer(ptr uint64) uint64 {
 	return value
 }
 
+type CacheSlidePointer4 uint32
+
+func (p CacheSlidePointer4) Raw() uint64 {
+	return uint64(p)
+}
+
+func (p CacheSlidePointer4) MarshalJSON() ([]byte, error) {
+	return json.Marshal(&struct {
+		Value uint32 `json:"value"`
+	}{
+		Value: uint32(p),
+	})
+}
+
 type CacheSlideInfo5 struct {
 	Version         uint32 `json:"slide_version,omitempty"` // currently 5
 	PageSize        uint32 `json:"page_size,omitempty"`     //  currently 4096 (may also be 16384)
