@@ -36,7 +36,7 @@ type TBD struct {
 }
 
 // NewTBD creates a new tbd object
-func NewTBD(image *dyld.CacheImage, reexports []string, private, generic bool) (*TBD, error) {
+func NewTBD(image *dyld.CacheImage, reexports []string, generic bool) (*TBD, error) {
 	var targets []string
 	var currentVersion string
 	var syms []string
@@ -138,16 +138,6 @@ func NewTBD(image *dyld.CacheImage, reexports []string, private, generic bool) (
 		}
 	}
 
-	// get private symbols
-	if private {
-		if err := image.ParseLocalSymbols(false); err != nil {
-			return nil, err
-		}
-		for _, sym := range image.LocalSymbols {
-			syms = append(syms, sym.Name)
-		}
-	}
-
 	// get objc classes and ivars
 	if m.HasObjC() {
 		classes, err := m.GetObjCClasses()
